@@ -44,8 +44,7 @@ def remove_stopwords(tokens: List[str], custom_stopwords: List[str] = []) -> Lis
     --------
     >>> from contextpro.normalization import remove_stopwords
     >>> tokens = ['My', 'name', 'is', 'Dr', 'Jekyll']
-    >>> result = remove_stopwords(tokens)
-    >>> print(result)
+    >>> remove_stopwords(tokens)
     ['My', 'name', 'Dr', 'Jekyll']
     """
 
@@ -73,8 +72,7 @@ def remove_non_ascii_characters(sentence: str) -> str:
     --------
     >>> from contextpro.normalization import remove_non_ascii_characters
     >>> sentence = "https://sitebulb.com/Folder/øê.html?大学"
-    >>> result = remove_non_ascii_characters(sentence)
-    >>> print(result)
+    >>> remove_non_ascii_characters(sentence)
     'https://sitebulb.com/Folder/.html?'
     """
     printable_chars = set(string.printable)
@@ -98,8 +96,7 @@ def remove_punctuation(sentence: str) -> str:
     --------
     >>> from contextpro.normalization import remove_punctuation
     >>> corpus = "My name is Dr. Jekyll."
-    >>> result = remove_punctuation(sentence)
-    >>> print(result)
+    >>> remove_punctuation(sentence)
     'My name is Dr Jekyll'
     """
     punctuation_chars = set(string.punctuation)
@@ -123,8 +120,7 @@ def remove_numbers(sentence: str) -> str:
     --------
     >>> from contextpro.normalization import remove_numbers
     >>> sentence = "He is 12 years old."
-    >>> result = remove_numbers(sentence)
-    >>> print(result)
+    >>> remove_numbers(sentence)
     'He is  years old.'
     """
     digit_chars = set(string.digits)
@@ -148,8 +144,7 @@ def remove_whitespace(sentence: str) -> str:
     --------
     >>> from contextpro.normalization import remove_whitespace
     >>> sentence = "He Has Not Been    in Touch for over a Month."
-    >>> result = remove_whitespace(sentence)
-    >>> print(result)
+    >>> remove_whitespace(sentence)
     'He Has Not Been in Touch for over a Month.'
     """
     return " ".join(re.split(r"\s+", sentence, flags=re.UNICODE))
@@ -172,8 +167,7 @@ def convert_numerals_to_numbers(sentence: str) -> str:
     --------
     >>> from contextpro.normalization import convert_numerals_to_numbers
     >>> sentence = "A bunch of five"
-    >>> result = convert_numerals_to_numbers(sentence)
-    >>> print(result)
+    >>> convert_numerals_to_numbers(sentence)
     'A bunch of 5'
     """
     spacy_doc = nlp(sentence)
@@ -204,38 +198,12 @@ def replace_contractions(sentence: str, **kwargs) -> str:
     --------
     >>> from contextpro.normalization import replace_contractions
     >>> sentence = "I don't want to be rude, but you shouldn't do this"
-    >>> result = replace_contractions(sentence)
-    >>> print(result)
+    >>> replace_contractions(sentence)
     'I do not want to be rude, but you should not do this'
     """
     return cast(str, contractions.fix(sentence, **kwargs))
 
 
-def lowercase_text(sentence: str) -> str:
-    """Converts sentence into lowercase.
-
-    Parameters
-    ----------
-    sentence : str
-        with characters of arbitrary size
-
-    Returns
-    -------
-    str
-        sentence with lowercased characters
-
-    Examples
-    --------
-    >>> from contextpro.normalization import lowercase_text
-    >>> sentence = "My name is Dr. Jekyll."
-
-    >>> result = lowercase_text(sentence)
-    >>> print(result)
-    'my name is dr. jekyll.'
-    """
-    return sentence.lower()
-
-
 def stem(
     tokens: List[str], stemmer_type: Optional[str] = "nltk_porter_stemmer", **kwargs
 ) -> List[str]:
@@ -274,8 +242,7 @@ def stem(
     --------
     >>> from contextpro.normalization import stem
     >>> tokens =  ["I", "like", "driving", "a", "car"]
-    >>> result = stem(tokens, stemmer_type="nltk_porter_stemmer")
-    >>> print(result)
+    >>> stem(tokens, stemmer_type="nltk_porter_stemmer")
     ['I', 'like', 'drive', 'a', 'car']
     """
 
@@ -320,27 +287,21 @@ def lemmatize(
     --------
     >>> from contextpro.normalization import lemmatize
     >>> tokens =  ["I", "like", "driving", "a", "car"]
-    >>> result = lemmatize(tokens, pos="v")
-    >>> print(result)
+    >>> lemmatize(tokens, pos="v")
     ['I', 'like', 'drive', 'a', 'car']
     """
     lemmatizer = WordNetLemmatizer()
     return [lemmatizer.lemmatize(word, **kwargs) for word in tokens]
 
 
-def batch_lowercase_text(
-    documents: List[str],
-    num_workers: Optional[int] = None,
-) -> List[str]:
-    """Converts sentences into lowercase in a concurrent manner.
+def batch_lowercase_text(documents: List[str]) -> List[str]:
+    """Converts sentences into lowercase.
 
     Parameters
     ----------
     documents : List[str]
         list of sentences with characters of arbitrary size
 
-    num_workers : Optional[int], optional
-        number of processors to use, by default None (all processors)
 
     Returns
     -------
@@ -361,11 +322,7 @@ def batch_lowercase_text(
     ...     "This guy's name is Edward Scissorhands",
     ...     "And this is Tom Parker"
     ... ]
-    >>> result = batch_lowercase_text(
-    ...     corpus,
-    ...     num_workers=2
-    ... )
-    >>> print(result)
+    >>> batch_lowercase_text(corpus)
     [
         "my name is dr. jekyll.",
         "his name is mr. hyde",
@@ -376,10 +333,7 @@ def batch_lowercase_text(
     if not _is_string_list(documents):
         raise ValueError("'documents' should be a list of strings")
 
-    return cast(
-        List[str],
-        _parallelize_func(lowercase_text, documents, num_workers=num_workers),
-    )
+    return [document.lower() for document in documents]
 
 
 def batch_remove_non_ascii_characters(
@@ -415,11 +369,7 @@ def batch_remove_non_ascii_characters(
     ...     "This is a \xA9 but not a \xAE"
     ...     "fractions \xBC, \xBD, \xBE"
     ... ]
-    >>> result = batch_remove_non_ascii_characters(
-    ...     corpus,
-    ...     num_workers=2
-    ... )
-    >>> print(result)
+    >>> batch_remove_non_ascii_characters(corpus, num_workers=2)
     [
         'https://sitebulb.com/Folder/.html?',
         'Jreskog bichen Zrcher',
@@ -475,11 +425,7 @@ def batch_replace_contractions(
     ...     "I'll see you next week",
     ...     "I'm going for a walk"
     ... ]
-    >>> result = batch_replace_contractions(
-    ...     corpus,
-    ...     num_workers=2
-    ... )
-    >>> print(result)
+    >>> batch_replace_contractions(corpus, num_workers=2)
     [
         'I do not want to be rude, but you should not do this',
         'Do you think he will pass his driving test?',
@@ -535,11 +481,7 @@ def batch_remove_stopwords(
     ...     ['This', 'guy', 's', 'name', 'is', 'Edward', 'Scissorhands'],
     ...     ['And', 'this', 'is', 'Tom', 'Parker']
     ... ]
-    >>> result = batch_remove_stopwords(
-    ...     corpus,
-    ...     num_workers=2
-    ... )
-    >>> print(result)
+    >>> batch_remove_stopwords(corpus, num_workers=2)
     [
         ['My', 'name', 'Dr', 'Jekyll'],
         ['His', 'name', 'Mr', 'Hyde'],
@@ -617,12 +559,11 @@ def batch_stem(
     ...     ["Do", "you", "think", "this", "is", "doable"],
     ...     ["I", "have", "three", "bikes", "in", "two", "garages"]
     ... ]
-    >>> result = batch_stem(
+    >>> batch_stem(
     ...    corpus,
     ...    stemmer_type="nltk_porter_stemmer",
     ...    num_workers=2
     ... )
-    >>> print(result)
     [
         ['I', 'like', 'drive', 'a', 'car'],
         ['I', 'am', 'go', 'for', 'a', 'walk'],
@@ -687,12 +628,7 @@ def batch_lemmatize(
     ...     ["What", "are", "you", "doing"],
     ...     ["Where", "are", "you", "coming", "from"]
     ... ]
-    >>> result = batch_lemmatize(
-    ...    corpus,
-    ...    num_workers=2,
-    ...    pos="v"
-    ... )
-    >>> print(result)
+    >>> batch_lemmatize(corpus, num_workers=2, pos="v")
     [
         ['I', 'like', 'drive', 'a', 'car'],
         ['I', 'be', 'go', 'for', 'a', 'walk'],
@@ -741,11 +677,10 @@ def batch_remove_punctuation(
     ...     "Is his name Edward Scissorhands?",
     ...     "This is Tom-Parker!"
     ... ]
-    >>> result = batch_remove_punctuation(
+    >>> batch_remove_punctuation(
     ...     corpus,
     ...     num_workers=2
     ... )
-    >>> print(result)
     [
         'My name is Dr Jekyll',
         'His name is Mr Hyde',
@@ -794,11 +729,10 @@ def batch_remove_numbers(
     ...     "I have 3 computers",
     ...     "He earns 1000$ daily"
     ... ]
-    >>> result = batch_remove_numbers(
+    >>> batch_remove_numbers(
     ...     corpus,
     ...     num_workers=2
     ... )
-    >>> print(result)
     [
         'He is  years old.',
         'His father has  cars',
@@ -847,11 +781,10 @@ def batch_remove_whitespace(
     ...     "I Am Hungry - Can We\t Eat Now, Please?",,
     ...     "It Is \r\nFreezing Outside!"
     ... ]
-    >>> result = batch_remove_whitespace(
+    >>> batch_remove_whitespace(
     ...     corpus,
     ...     num_workers=2
     ... )
-    >>> print(result)
     [
         'He Has Not Been in Touch for over a Month.',
         'I Will See You next Week',
@@ -902,11 +835,10 @@ def batch_convert_numerals_to_numbers(
     ...     "Behind the eight ball",
     ...     "Between two stools",
     ... ]
-    >>> result = batch_convert_numerals_to_numbers(
+    >>> batch_convert_numerals_to_numbers(
     ...     corpus,
     ...     num_workers=2
     ... )
-    >>> print(result)
     [
         'A bunch of 5',
         'A picture is worth a 1000 words',
@@ -935,10 +867,8 @@ __all__ = [
     "remove_whitespace",
     "convert_numerals_to_numbers",
     "replace_contractions",
-    "lowercase_text",
     "stem",
     "lemmatize",
-    "batch_lowercase_text",
     "batch_remove_non_ascii_characters",
     "batch_replace_contractions",
     "batch_remove_stopwords",
