@@ -5,14 +5,56 @@ import string
 from typing import Any, Dict, Iterable, List, Optional, cast
 
 import pandas as pd
+from nltk.probability import FreqDist
 from textblob import TextBlob
 
-from contextpro._processing import _is_string_list, _parallelize_func
-from contextpro.feature_extraction import ConcurrentCountVectorizer
+from contextpro._processing import (
+    _is_nested_string_list,
+    _is_string_list,
+    _parallelize_func,
+)
+from contextpro.feature_extraction import batch_get_ngrams, get_ngrams
 from contextpro.normalization import batch_lowercase_text, batch_remove_stopwords
 from contextpro.tokenization import batch_tokenize_text
 
 
+def get_ngram_counts(tokens: List[str], ngram_size: int = 1) -> Dict[str, int]:
+    """Calculate ngram counts in a tokenized document.
+
+    Parameters
+    ----------
+    tokens : List[str]
+        list of tokens
+
+    ngram_size : str, optional
+        size of ngrams to calculate, by default 1 - unigrams
+
+    Returns
+    -------
+    Dict[str, int]
+        mapping from ngram to the number of occurrences in a document
+
+    Raises
+    ------
+    ValueError
+        if 'tokens' provided is not a list of strings
+
+    Examples
+    --------
+    >>> from contextpro.statistics import get_ngram_counts
+    >>> tokens = ["my", "name", "is", "dr", "jekyll"]
+    >>> get_ngram_counts(tokens, ngram_size=1)
+    {'my': 1, 'name': 1, 'is': 1, 'dr': 1, 'jekyll': 1}
+     >>> get_ngram_counts(tokens, ngram_size=2)
+    {'my name': 1, 'name is': 1, 'is dr': 1, 'dr jekyll': 1}
+    """
+
+    if not _is_string_list(tokens):
+        raise ValueError("'tokens' should be a list of strings")
+
+    return _count_grams(get_ngrams(tokens, ngram_size=ngram_size))
+
+
 def calculate_sentiment_score(document: str) -> float:
     """Calculate sentiment score for the sentence using TextBlob object.
 
@@ -31,8 +73,7 @@ def calculate_sentiment_score(document: str) -> float:
     --------
     >>> from contextpro.statistics import calculate_sentiment_score
     >>> corpus = "I love the Spiderman movie"
-    >>> score = calculate_sentiment_score(sentence)
-    >>> print(score)
+    >>> calculate_sentiment_score(sentence)
     0.5
     """
     return float(TextBlob(document).polarity)
@@ -57,13 +98,65 @@ def calculate_subjectivity_score(document: str) -> float:
     --------
     >>> from contextpro.statistics import calculate_subjectivity_score
     >>> corpus = "I love the Spiderman movie"
-    >>> score = calculate_subjectivity_score(sentence)
-    >>> print(score)
+    >>> calculate_subjectivity_score(sentence)
     0.6
     """
     return float(TextBlob(document).subjectivity)
 
 
+def batch_get_ngram_counts(
+    tokens: List[List[str]], ngram_size: int = 1
+) -> Dict[str, int]:
+    """Calculate ngram counts across the corpus of tokenized documents.
+
+    Parameters
+    ----------
+    tokens : List[List[str]]
+        list of nested token lists
+
+    ngram_size : str, optional
+        size of ngrams to calculate, by default 1 - unigrams
+
+    Returns
+    -------
+    Dict[str, int]
+        mapping from ngram to the number of occurrences in a
+        corpus of tokenized documents
+
+    Raises
+    ------
+    ValueError
+        if 'tokens' provided is not a list of nested token lists
+
+    Examples
+    --------
+    >>> from contextpro.statistics import get_ngram_counts
+    >>> corpus = [
+        ["my", "name", "is", "dr", "jekyll"],
+        ["his", "name", "is", "mr", "hyde"],
+        ["this", "guy", "name", "is", "edward", "scissorhands"],
+        ["and", "this", "is", "tom", "parker"],
+    ]
+    >>> batch_get_ngram_counts(corpus, ngram_size=1)
+    {
+        'my': 1, 'name': 3, 'is': 4, 'dr': 1, 'jekyll': 1, 'his': 1,
+        'mr': 1, 'hyde': 1, 'this': 2, 'guy': 1, 'edward': 1,
+        'scissorhands': 1, 'and': 1, 'tom': 1, 'parker': 1
+    }
+    >>> batch_get_ngram_counts(corpus, ngram_size=2)
+    {
+        "my name": 1, "name is": 3, "is dr": 1, "dr jekyll": 1,
+        "his name": 1, "is mr": 1, "mr hyde": 1, "this guy": 1,
+        "guy name": 1, "is edward": 1, "edward scissorhands": 1,
+        "and this": 1, "this is": 1, "is tom": 1, "tom parker": 1
+    }
+    """
+    if not _is_nested_string_list(tokens):
+        raise ValueError("'tokens' should be a list of nested string lists")
+
+    return _batch_count_grams(batch_get_ngrams(tokens, ngram_size=ngram_size))
+
+
 def batch_calculate_sentiment_scores(
     documents: List[str], num_workers: Optional[int] = None
 ) -> List[float]:
@@ -97,11 +190,10 @@ def batch_calculate_sentiment_scores(
     ...     "In my opinion this movie was rather boring than exciting",
     ...     "This is the worst movie I've ever seen"
     ... ]
-    >>> scores = batch_calculate_sentiment_scores(
+    >>> batch_calculate_sentiment_scores(
     ...     corpus,
     ...     num_workers=2
     ... )
-    >>> print(scores)
     [0.0, 0.5, -0.35, -1.0]
     """
     if not _is_string_list(documents):
@@ -149,11 +241,10 @@ def batch_calculate_subjectivity_scores(
     ...     "In my opinion this movie was rather boring than exciting",
     ...     "This is the worst movie I've ever seen"
     ... ]
-    >>> scores = batch_calculate_subjectivity_scores(
+    >>> batch_calculate_subjectivity_scores(
     ...     corpus,
     ...     num_workers=2
     ... )
-    >>> print(scores)
     [0.0, 0.6, 0.9, 1.0]
     """
     if not _is_string_list(documents):
@@ -167,115 +258,6 @@ def batch_calculate_subjectivity_scores(
     )
 
 
-def batch_get_ngram_counts(
-    documents: List[str],
-    ngram_type: str = "unigram",
-    lowercase: bool = True,
-    remove_stopwords: bool = True,
-    num_workers: Optional[int] = None,
-) -> Optional[Dict[str, int]]:
-    """Count the number of n-grams across the documents corpus in a
-    concurrent manner.
-
-    Parameters
-    ----------
-    documents : List[str]
-        list of strings
-
-    ngram_type : str, optional
-        type of n-grams to count, by default "unigram"
-
-        Allowed values:
-          - 'unigram'
-          - 'bigram'
-          - 'trigram'
-
-    lowercase : bool, optional
-        lowercase the documents before deriving unigrams,
-        by default True
-
-    remove_stopwords : bool, optional
-        remove stopwords before deriving unigrams, by default True
-
-    num_workers : Optional[int], optional
-        number of processors to use, by default None (all processors)
-
-    Returns
-    -------
-    Optional[Dict[str, int]]
-        mapping from unigram to the number of occurrences in corpus
-
-    Raises
-    ------
-    ValueError
-        if 'documents' provided are not a list of strings
-
-    Examples
-    --------
-    >>> from contextpro.statistics import batch_get_ngram_counts
-    >>> corpus = [
-    ...     "My name is Dr. Jekyll.",
-    ...     "His name is Mr. Hyde",
-    ...     "This guy's name is Edward Scissorhands",
-    ...     "And this is Tom Parker"
-    ... ]
-    >>> unigrams = batch_get_ngram_counts(
-    ...     corpus,
-    ...     ngram_type="unigram",
-    ...     lowercase=True,
-    ...     remove_stopwords=True,
-    ...     num_workers=4,
-    ... )
-    >>> print(unigrams)
-    {
-        'dr': 1, 'edward': 1, 'guy': 1, 'hyde': 1, 'jekyll': 1,
-        'mr': 1, 'name': 3, 'parker': 1, 'scissorhands': 1, 'tom': 1
-    }
-    >>> bigrams = batch_get_ngram_counts(
-    ...     corpus,
-    ...     ngram_type="bigram",
-    ...     lowercase=True,
-    ...     remove_stopwords=True,
-    ...     num_workers=4,
-    ... )
-    >>> print(bigrams)
-    {
-        'dr jekyll': 1, 'edward scissorhands': 1, 'guy name': 1,
-        'mr hyde': 1, 'name dr': 1, 'name edward': 1, 'name mr': 1,
-        'tom parker': 1
-    }
-    >>> trigrams = batch_get_ngram_counts(
-    ...     corpus,
-    ...     ngram_type="trigram",
-    ...     lowercase=True,
-    ...     remove_stopwords=True,
-    ...     num_workers=2,
-    ... )
-    >>> print(trigrams)
-    {
-        'guy name edward': 1, 'name dr jekyll': 1,
-        'name edward scissorhands': 1, 'name mr hyde': 1
-    }
-    """
-    if not _is_string_list(documents):
-        raise ValueError("'documents' should be a list of strings")
-
-    vectorizer = ConcurrentCountVectorizer(
-        lowercase=lowercase,
-        remove_stopwords=remove_stopwords,
-        ngram_range=(1, 1),
-        num_workers=num_workers,
-    )
-    vectorizer.fit(documents)
-
-    if ngram_type == "unigram":
-        return vectorizer.get_unigram_counts()
-    elif ngram_type == "bigram":
-        return vectorizer.get_bigram_counts()
-    else:
-        return vectorizer.get_trigram_counts()
-
-
 def batch_calculate_corpus_statistics(
     documents: List[str],
     lowercase: bool = False,
@@ -339,13 +321,12 @@ def batch_calculate_corpus_statistics(
     ...     "This guy's name is Edward Scissorhands",
     ...     "And this is Tom Parker"
     ... ]
-    >>> statistics = batch_calculate_corpus_statistics(
+    >>> batch_calculate_corpus_statistics(
     ...     corpus,
     ...     lowercase=False,
     ...     remove_stopwords=False,
     ...     num_workers=2,
     ... )
-    >>> print(statistics)
         characters  tokens  punctuation_characters  digits  whitespace_characters  \
     0          22       5                       2       0                      4
     1          20       5                       1       0                      4
@@ -362,7 +343,7 @@ def batch_calculate_corpus_statistics(
         raise ValueError("'documents' should be a list of strings")
 
     if lowercase:
-        documents = batch_lowercase_text(documents, num_workers=num_workers)
+        documents = batch_lowercase_text(documents)
 
     tokens = batch_tokenize_text(
         documents,
@@ -451,11 +432,24 @@ def _batch_calculate_chars(
     )
 
 
+def _count_grams(ngrams: List[str]) -> Dict[str, int]:
+    """Calculate n-gram counts in a document."""
+    dist = FreqDist(ngrams)
+    return {ngram: count for ngram, count in zip(dist.keys(), dist.values())}
+
+
+def _batch_count_grams(ngrams: List[List[str]]) -> Dict[str, int]:
+    """Calculate n-gram counts for the corpus of documents"""
+    flat_grams = [ngram for doc in ngrams for ngram in doc]
+    return _count_grams(flat_grams)
+
+
 __all__ = [
+    "get_ngram_counts",
+    "batch_get_ngram_counts",
     "calculate_sentiment_score",
     "calculate_subjectivity_score",
     "batch_calculate_sentiment_scores",
     "batch_calculate_subjectivity_scores",
-    "batch_get_ngram_counts",
     "batch_calculate_corpus_statistics",
 ]
