@@ -57,14 +57,13 @@ def batch_tokenize_text(
     ...     "This guy's name is Edward Scissorhands",
     ...     "And this is Tom Parker"
     ... ]
-    >>> tokens = batch_tokenize_text(
+    >>> batch_tokenize_text(
     ...     corpus,
     ...     tokenizer_method="nltk_regexp_tokenizer",
     ...     pattern=r"\b[^\d\W]+\b",
     ...     gaps=False,
     ...     num_workers=2
     ... )
-    >>> print(tokens)
     [['My', 'name', 'is', 'Dr', 'Jekyll'],
      ['His', 'name', 'is', 'Mr', 'Hyde'],
      ['This', 'guy', 's', 'name', 'is', 'Edward', 'Scissorhands'],
@@ -121,20 +120,19 @@ def tokenize_text(
     --------
     >>> from contextpro.tokenization import tokenize_text
     >>> sentence = "My name is Dr. Jekyll."
-    >>> tokens = tokenize_text(
+    >>> tokenize_text(
     ...     corpus,
     ...     tokenizer_method="nltk_regexp_tokenizer",
     ...     pattern=r"\b[^\d\W]+\b",
     ...     gaps=False,
     ... )
-    >>> print(tokens)
     ['My', 'name', 'is', 'Dr', 'Jekyll']
     """
-    if tokenizer_method == "nltk_word_tokenizer":  # pragma: no cover
+    if tokenizer_method == "nltk_word_tokenizer":
         tokens = nltk.word_tokenize(document, **kwargs)
-    elif tokenizer_method == "nltk_regexp_tokenizer":  # pragma: no cover
+    elif tokenizer_method == "nltk_regexp_tokenizer":
         tokens = nltk.regexp_tokenize(document, **kwargs)
-    return cast(List[str], tokens)  # pragma: no cover
+    return cast(List[str], tokens)
 
 
 __all__ = ["tokenize_text", "batch_tokenize_text"]
